==> tough-ssm-0.6.1.crate: tough-ssm-0.6.1/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.6.1] - 2021-07-30
### Changes
- Update dependencies.  [#363], [#364], [#365], [#366], [#367], [#379], [#381], [#382], [#384], [#391], [#393], [#396], [#398]
- Fix clippy warnings.  [#372], [#378], [#383], [#399]
- Add license check to CI.  [#385]

[#363]: https://github.com/awslabs/tough/pull/363
[#364]: https://github.com/awslabs/tough/pull/364
[#365]: https://github.com/awslabs/tough/pull/365
[#366]: https://github.com/awslabs/tough/pull/366
[#367]: https://github.com/awslabs/tough/pull/367
[#372]: https://github.com/awslabs/tough/pull/372
[#378]: https://github.com/awslabs/tough/pull/378
[#379]: https://github.com/awslabs/tough/pull/379
[#381]: https://github.com/awslabs/tough/pull/381
[#382]: https://github.com/awslabs/tough/pull/382
[#383]: https://github.com/awslabs/tough/pull/383
[#384]: https://github.com/awslabs/tough/pull/384
[#385]: https://github.com/awslabs/tough/pull/385
[#391]: https://github.com/awslabs/tough/pull/391
[#393]: https://github.com/awslabs/tough/pull/393
[#396]: https://github.com/awslabs/tough/pull/396
[#398]: https://github.com/awslabs/tough/pull/398
[#399]: https://github.com/awslabs/tough/pull/399

## [0.6.0] - 2021-03-01
### Breaking Changes
- Update `tokio` to v1. [#330]
- Update `rusoto` to 0.46. [#330]
- Update `tough` to 0.11.0.

[#330]: https://github.com/awslabs/tough/pull/330

## [0.5.0] - 2021-01-19
### Changed
- Update `tough` dependency to 0.10.0.
- Update `rusoto` dependency to 0.45.0.

## [0.4.0] - 2020-09-17
### Changed
- Update `tough` dependency to 0.9.0.

## [0.3.0] - 2020-07-20
### Added
- Added CI build of `tough-ssm`.

### Changed
- Update `tough` dependency to 0.8.0.

## [0.2.0] - 2020-06-26
### Changed
- Update `tough` dependency to 0.7.0.

## [0.1.0] - 2020-06-11
### Added
- Everything!

[0.6.1]: https://github.com/awslabs/tough/compare/tough-ssm-v0.6.0...tough-ssm-v0.6.1
[0.6.0]: https://github.com/awslabs/tough/compare/tough-ssm-v0.5.0...tough-ssm-v0.6.0
[0.5.0]: https://github.com/awslabs/tough/compare/tough-ssm-v0.4.0...tough-ssm-v0.5.0
[0.4.0]: https://github.com/awslabs/tough/compare/tough-ssm-v0.3.0...tough-ssm-v0.4.0
[0.3.0]: https://github.com/awslabs/tough/compare/tough-ssm-v0.2.0...tough-ssm-v0.3.0
[0.2.0]: https://github.com/awslabs/tough/compare/tough-ssm-v0.1.0...tough-ssm-v0.2.0
[0.1.0]: https://github.com/awslabs/tough/releases/tag/tough-ssm-v0.1.0

==> tough-ssm-0.6.2.crate: tough-ssm-0.6.2/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.6.2] - 2021-08-24
### Changes
- Update `tough` dependency to 0.11.2

## [0.6.1] - 2021-07-30
### Changes
- Update dependencies.  [#363], [#364], [#365], [#366], [#367], [#379], [#381], [#382], [#384], [#391], [#393], [#396], [#398]
- Fix clippy warnings.  [#372], [#378], [#383], [#399]
- Add license check to CI.  [#385]

[#363]: https://github.com/awslabs/tough/pull/363
[#364]: https://github.com/awslabs/tough/pull/364
[#365]: https://github.com/awslabs/tough/pull/365
[#366]: https://github.com/awslabs/tough/pull/366
[#367]: https://github.com/awslabs/tough/pull/367
[#372]: https://github.com/awslabs/tough/pull/372
[#378]: https://github.com/awslabs/tough/pull/378
[#379]: https://github.com/awslabs/tough/pull/379
[#381]: https://github.com/awslabs/tough/pull/381
[#382]: https://github.com/awslabs/tough/pull/382
[#383]: https://github.com/awslabs/tough/pull/383
[#384]: https://github.com/awslabs/tough/pull/384
[#385]: https://github.com/awslabs/tough/pull/385
[#391]: https://github.com/awslabs/tough/pull/391
[#393]: https://github.com/awslabs/tough/pull/393
[#396]: https://github.com/awslabs/tough/pull/396
[#398]: https://github.com/awslabs/tough/pull/398
[#399]: https://github.com/awslabs/tough/pull/399

## [0.6.0] - 2021-03-01
### Breaking Changes
- Update `tokio` to v1. [#330]
- Update `rusoto` to 0.46. [#330]
- Update `tough` to 0.11.0.

[#330]: https://github.com/awslabs/tough/pull/330

## [0.5.0] - 2021-01-19
### Changed
- Update `tough` dependency to 0.10.0.
- Update `rusoto` dependency to 0.45.0.

## [0.4.0] - 2020-09-17
### Changed
- Update `tough` dependency to 0.9.0.

## [0.3.0] - 2020-07-20
### Added
- Added CI build of `tough-ssm`.

### Changed
- Update `tough` dependency to 0.8.0.

## [0.2.0] - 2020-06-26
### Changed
- Update `tough` dependency to 0.7.0.

## [0.1.0] - 2020-06-11
### Added
- Everything!

[0.6.2]: https://github.com/awslabs/tough/compare/tough-ssm-v0.6.1...tough-ssm-v0.6.2
[0.6.1]: https://github.com/awslabs/tough/compare/tough-ssm-v0.6.0...tough-ssm-v0.6.1
[0.6.0]: https://github.com/awslabs/tough/compare/tough-ssm-v0.5.0...tough-ssm-v0.6.0
[0.5.0]: https://github.com/awslabs/tough/compare/tough-ssm-v0.4.0...tough-ssm-v0.5.0
[0.4.0]: https://github.com/awslabs/tough/compare/tough-ssm-v0.3.0...tough-ssm-v0.4.0
[0.3.0]: https://github.com/awslabs/tough/compare/tough-ssm-v0.2.0...tough-ssm-v0.3.0
[0.2.0]: https://github.com/awslabs/tough/compare/tough-ssm-v0.1.0...tough-ssm-v0.2.0
[0.1.0]: https://github.com/awslabs/tough/releases/tag/tough-ssm-v0.1.0
